@@ -35,6 +35,9 @@
 /* Define to empty if the keyword does not work.  */
 #undef const
 
+/* Define to empty if the volatile keyword does not work.  */
+#undef volatile
+
 /* Define to one of _getb67, GETB67, getb67 for Cray-2 and Cray-YMP systems.
    This function is required for alloca.c support on those systems.  */
 #undef CRAY_STACKSEG_END
@@ -104,6 +107,9 @@
 /* Define if you have the strftime function.  */
 #undef HAVE_STRFTIME
 
+/* Define if you have the ANSI # stringizing operator in cpp. */
+#undef HAVE_STRINGIZE
+
 /* Define if you have <sys/wait.h> that is POSIX.1 compatible.  */
 #undef HAVE_SYS_WAIT_H
 
@@ -147,9 +153,6 @@
 /* Define if on MINIX.  */
 #undef _MINIX
 
-/* Define to `int' if <sys/types.h> doesn't define.  */
-#undef mode_t
-
 /* Define if you don't have <dirent.h>, but have <ndir.h>.  */
 #undef NDIR
 
@@ -166,11 +169,8 @@
 /* Define if your C compiler doesn't accept -c and -o together.  */
 #undef NO_MINUS_C_MINUS_O
 
-/* Define to `long' if <sys/types.h> doesn't define.  */
-#undef off_t
-
-/* Define to `int' if <sys/types.h> doesn't define.  */
-#undef pid_t
+/* Define if your Fortran 77 compiler doesn't accept -c and -o together. */
+#undef F77_NO_MINUS_C_MINUS_O
 
 /* Define if the system does not provide POSIX.1 features except
    with this defined.  */
@@ -182,6 +182,15 @@
 /* Define as the return type of signal handlers (int or void).  */
 #undef RETSIGTYPE
 
+/* Define to the type of arg1 for select(). */
+#undef SELECT_TYPE_ARG1
+
+/* Define to the type of args 2, 3 and 4 for select(). */
+#undef SELECT_TYPE_ARG234
+
+/* Define to the type of arg5 for select(). */
+#undef SELECT_TYPE_ARG5
+
 /* Define if the `setpgrp' function takes no argument.  */
 #undef SETPGRP_VOID
 
@@ -190,9 +199,6 @@
    before release 3.  */
 #undef SETVBUF_REVERSED
 
-/* Define to `unsigned' if <sys/types.h> doesn't define.  */
-#undef size_t
-
 /* If using the C implementation of alloca, define if you know the
    direction of stack growth for your system; otherwise it will be
    automatically deduced at run-time.
